==> haskell-crypto-random-0.0.9-257-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-random
version:              0.0.9
visibility:           public
id:                   crypto-random-0.0.9-2exiX5OsJlU9ffYtdUd5sx
key:                  crypto-random-0.0.9-2exiX5OsJlU9ffYtdUd5sx
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-random
synopsis:             Simple cryptographic random related types
description:          Simple cryptographic random related types
category:             Cryptography
abi:                  ea5bc7360ee9dd6b5e01228823a61f3c
exposed:              True
exposed-modules:      Crypto.Random Crypto.Random.API Crypto.Random.Test
hidden-modules:
    Crypto.Random.Generator Crypto.Random.Entropy
    Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix
    Crypto.Random.Entropy.RDRand

import-dirs:          /usr/lib/ghc-9.0.2/site-local/crypto-random-0.0.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/crypto-random-0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/crypto-random-0.0.9
hs-libraries:         HScrypto-random-0.0.9-2exiX5OsJlU9ffYtdUd5sx
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    securemem-0.1.10-Bd4DajDBrG9HFY3HcdakkQ unix-2.7.2.2
    vector-0.12.3.1-FGR30quEvBKIVgcX0eclul

haddock-interfaces:
    /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock

haddock-html:         /usr/share/doc/haskell-crypto-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-random-0.0.9-263-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-random
version:              0.0.9
visibility:           public
id:                   crypto-random-0.0.9-8BI9OuoFvQpI2xnV3KbiOK
key:                  crypto-random-0.0.9-8BI9OuoFvQpI2xnV3KbiOK
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             http://github.com/vincenthz/hs-crypto-random
synopsis:             Simple cryptographic random related types
description:          Simple cryptographic random related types
category:             Cryptography
abi:                  8457b848c65a090395045f7a28d9df4a
exposed:              True
exposed-modules:      Crypto.Random Crypto.Random.API Crypto.Random.Test
hidden-modules:
    Crypto.Random.Generator Crypto.Random.Entropy
    Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix
    Crypto.Random.Entropy.RDRand

import-dirs:          /usr/lib/ghc-9.0.2/site-local/crypto-random-0.0.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/crypto-random-0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/crypto-random-0.0.9
hs-libraries:         HScrypto-random-0.0.9-8BI9OuoFvQpI2xnV3KbiOK
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    securemem-0.1.10-6QzN0fGwj6UJJ4P3JoJYKy unix-2.7.2.2
    vector-0.12.3.1-5HK1DqtCbep8rMk53O5plV

haddock-interfaces:
    /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock

haddock-html:         /usr/share/doc/haskell-crypto-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
